@@ -13,11 +13,7 @@
 #include <QListWidgetItem>
 #include <QPointer>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
 #include <qt6keychain/keychain.h>
-#endif
 using namespace QKeychain;
 ServerSieveListWidget::ServerSieveListWidget(QWidget *parent)
     : QListWidget(parent)
@@ -34,7 +30,7 @@ void ServerSieveListWidget::readConfig()
     job->start();
 }
 
-void ServerSieveListWidget::slotReadServerSieveConfigDone(const QVector<SieveEditorUtil::SieveServerConfig> &lstConfig)
+void ServerSieveListWidget::slotReadServerSieveConfigDone(const QList<SieveEditorUtil::SieveServerConfig> &lstConfig)
 {
     for (const SieveEditorUtil::SieveServerConfig &conf : lstConfig) {
         auto item = new ServerSieveListWidgetItem(this);
@@ -44,7 +40,7 @@ void ServerSieveListWidget::slotReadServerSieveConfigDone(const QVector<SieveEdi
 
 void ServerSieveListWidget::writeConfig()
 {
-    QVector<SieveEditorUtil::SieveServerConfig> lstServerConfig;
+    QList<SieveEditorUtil::SieveServerConfig> lstServerConfig;
     for (int i = 0; i < count(); ++i) {
         auto serverSieveItem = static_cast<ServerSieveListWidgetItem *>(item(i));
         if (serverSieveItem) {
@@ -127,3 +123,5 @@ void ServerSieveListWidgetItem::setServerConfig(const SieveEditorUtil::SieveServ
     setText(i18nc("server name (username)", "%1 (%2)", conf.sieveSettings.serverName, conf.sieveSettings.userName));
     mServerConfig = conf;
 }
+
+#include "moc_serversievelistwidget.cpp"
