@@ -6,8 +6,11 @@
 
 #pragma once
 
+#include <KBookmarkManager>
 #include <KBookmarkOwner>
+
 #include <QObject>
+
 class KBookmarkMenu;
 class QMenu;
 class KActionCollection;
@@ -23,14 +26,15 @@ public:
 
     void openBookmark(const KBookmark &bm, Qt::MouseButtons mb, Qt::KeyboardModifiers km) override;
 
-    Q_REQUIRED_RESULT QString currentTitle() const override;
-    Q_REQUIRED_RESULT QUrl currentUrl() const override;
+    [[nodiscard]] QString currentTitle() const override;
+    [[nodiscard]] QUrl currentUrl() const override;
 
 Q_SIGNALS:
     void openUrl(const QUrl &url);
 
 private:
     Q_DISABLE_COPY(SieveEditorBookmarks)
+    KBookmarkManager *m_bookmarkManager;
     KBookmarkMenu *mBookmarkMenu = nullptr;
     QMenu *const mMenu;
     SieveEditorMainWindow *const mMainWindow;
