@@ -7,17 +7,27 @@
 #include "sieveeditorcentralwidget.h"
 #include "sieveeditorconfigureserverpage.h"
 #include "sieveeditormainwidget.h"
+#include <PimCommon/PurposeMenuMessageWidget>
+#include <QVBoxLayout>
 
 SieveEditorCentralWidget::SieveEditorCentralWidget(QWidget *parent, KActionCollection *ac)
     : QStackedWidget(parent)
+    , mPurposeMenuMessageWidget(new PimCommon::PurposeMenuMessageWidget(this))
+    , mMainWidget(new QWidget)
 {
     mConfigureWidget = new SieveEditorConfigureServerPage;
     connect(mConfigureWidget, &SieveEditorConfigureServerPage::configureClicked, this, &SieveEditorCentralWidget::configureClicked);
     connect(mConfigureWidget, &SieveEditorConfigureServerPage::importSieveSettings, this, &SieveEditorCentralWidget::importSieveSettings);
     addWidget(mConfigureWidget);
+
+    auto mainWidgetLayout = new QVBoxLayout(mMainWidget);
+    mainWidgetLayout->setContentsMargins({});
+
     mSieveEditorMainWidget = new SieveEditorMainWidget(ac);
+    mainWidgetLayout->addWidget(mPurposeMenuMessageWidget);
+    mainWidgetLayout->addWidget(mSieveEditorMainWidget);
     connect(mSieveEditorMainWidget, &SieveEditorMainWidget::serverSieveFound, this, &SieveEditorCentralWidget::slotServerSieveFound);
-    addWidget(mSieveEditorMainWidget);
+    addWidget(mMainWidget);
     setCurrentWidget(mConfigureWidget);
 }
 
@@ -26,7 +36,7 @@ SieveEditorCentralWidget::~SieveEditorCentralWidget() = default;
 void SieveEditorCentralWidget::slotServerSieveFound(bool hasServer)
 {
     if (hasServer) {
-        setCurrentWidget(mSieveEditorMainWidget);
+        setCurrentWidget(mMainWidget);
     } else {
         setCurrentWidget(mConfigureWidget);
     }
@@ -36,3 +46,15 @@ SieveEditorMainWidget *SieveEditorCentralWidget::sieveEditorMainWidget() const
 {
     return mSieveEditorMainWidget;
 }
+
+void SieveEditorCentralWidget::slotShareError(const QString &message)
+{
+    mPurposeMenuMessageWidget->slotShareError(message);
+}
+
+void SieveEditorCentralWidget::slotShareSuccess(const QString &message)
+{
+    mPurposeMenuMessageWidget->slotShareSuccess(message);
+}
+
+#include "moc_sieveeditorcentralwidget.cpp"
