@@ -11,13 +11,8 @@
 
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/FeedbackConfigWidget>
 #include <KUserFeedbackQt6/Provider>
-#else
-#include <KUserFeedback/FeedbackConfigWidget>
-#include <KUserFeedback/Provider>
-#endif
 #endif
 
 #include <KLocalizedString>
@@ -119,14 +114,16 @@ void SieveEditorConfigureDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorConfigureDialog);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorConfigureDialog));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SieveEditorConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorConfigureDialog);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorConfigureDialog));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
+
+#include "moc_sieveeditorconfiguredialog.cpp"
