@@ -21,7 +21,7 @@ void SieveEditorEmptyTabWidgetLabel::init()
     QString placeholderText = QStringLiteral(
         "<html><body style=\"color:#909090; font-size:14px\">"
         "<div align='center'>");
-    const QVector<placeHolderTextInfo> map{
+    const QList<placeHolderTextInfo> map{
         placeHolderTextInfo(i18n("Import script:"), i18nc("Action is from file menu, import submenu", "File > Import")),
         placeHolderTextInfo(i18n("Create Rules Graphically:"), i18nc("Action is from menu tools, submenu autogenerate script", "Tools > Autogenerate script")),
         placeHolderTextInfo(i18n("Debug a script:"), i18nc("These action in from menu tools submenu debug sieve script", "Tools > Debug Sieve Script")),
@@ -35,7 +35,7 @@ void SieveEditorEmptyTabWidgetLabel::init()
     setText(placeholderText);
 }
 
-void SieveEditorEmptyTabWidgetLabel::addInfo(QString &placeholderText, const QVector<placeHolderTextInfo> &map)
+void SieveEditorEmptyTabWidgetLabel::addInfo(QString &placeholderText, const QList<placeHolderTextInfo> &map)
 {
     for (int i = 0; i < map.size(); ++i) {
         placeholderText += QStringLiteral(
@@ -45,3 +45,5 @@ void SieveEditorEmptyTabWidgetLabel::addInfo(QString &placeholderText, const QVe
                                .arg(map.at(i).text, map.at(i).menuInfo);
     }
 }
+
+#include "moc_sieveeditoremptytabwidgetlabel.cpp"
