@@ -54,18 +54,15 @@ SieveEditorMainWidget::SieveEditorMainWidget(KActionCollection *ac, QWidget *par
     setChildrenCollapsible(false);
     QList<int> splitterSizes;
     splitterSizes << 80 << 20;
-    KConfigGroup myGroup(KSharedConfig::openStateConfig(), mySieveEditorMainWidgetConfigGroupName);
+    KConfigGroup myGroup(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorMainWidgetConfigGroupName));
     setSizes(myGroup.readEntry("mainSplitter", splitterSizes));
     updateStackedWidget();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(qApp, &QApplication::paletteChanged, this, &SieveEditorMainWidget::slotGeneralPaletteChanged);
-#endif
 }
 
 SieveEditorMainWidget::~SieveEditorMainWidget()
 {
     disconnect(mScriptManagerWidget, &SieveEditorScriptManagerWidget::updateButtons, this, &SieveEditorMainWidget::updateButtons);
-    KConfigGroup myGroup(KSharedConfig::openStateConfig(), mySieveEditorMainWidgetConfigGroupName);
+    KConfigGroup myGroup(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorMainWidgetConfigGroupName));
     myGroup.writeEntry("mainSplitter", sizes());
     myGroup.sync();
 }
@@ -607,7 +604,7 @@ void SieveEditorMainWidget::slotTabCloseRequested(int index)
         if (page->isModified()) {
             const int result = KMessageBox::questionTwoActionsCancel(this,
                                                                      i18n("Script was modified. Do you want to save before closing?"),
-                                                                     i18n("Close script"),
+                                                                     i18nc("@title:window", "Close script"),
                                                                      KStandardGuiItem::save(),
                                                                      KStandardGuiItem::close(),
                                                                      KStandardGuiItem::cancel());
@@ -715,10 +712,10 @@ bool SieveEditorMainWidget::isTextEditor() const
 
 bool SieveEditorMainWidget::event(QEvent *e)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (e->type() == QEvent::ApplicationPaletteChange) {
         slotGeneralPaletteChanged();
     }
-#endif
     return QSplitter::event(e);
 }
+
+#include "moc_sieveeditormainwidget.cpp"
