@@ -21,6 +21,7 @@
 #include <PimCommon/NetworkManager>
 
 #include <KActionCollection>
+#include <KColorSchemeMenu>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KStandardAction>
@@ -39,13 +40,8 @@
 #include <QToolButton>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/NotificationPopup>
 #include <KUserFeedbackQt6/Provider>
-#else
-#include <KUserFeedback/NotificationPopup>
-#include <KUserFeedback/Provider>
-#endif
 #endif
 
 #include <KWindowConfig>
@@ -99,14 +95,14 @@ void SieveEditorMainWindow::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(800, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorMainWindowConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorMainWindowConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SieveEditorMainWindow::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), mySieveEditorMainWindowConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySieveEditorMainWindowConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
@@ -208,6 +204,8 @@ void SieveEditorMainWindow::setupActions()
     mShareAction->setMenu(purposeMenu->menu());
     mShareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
     purposeMenu->setEditorWidget(mMainWidget->sieveEditorMainWidget());
+    connect(purposeMenu, &SievePurposeMenuWidget::shareError, mMainWidget, &SieveEditorCentralWidget::slotShareError);
+    connect(purposeMenu, &SievePurposeMenuWidget::shareSuccess, mMainWidget, &SieveEditorCentralWidget::slotShareSuccess);
 
     mSpellCheckAction = new QAction(i18n("Check Spelling..."), this);
     connect(mSpellCheckAction, &QAction::triggered, mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::slotCheckSpelling);
@@ -286,7 +284,7 @@ void SieveEditorMainWindow::setupActions()
     connect(mShowFullScreenAction, &QAction::toggled, this, &SieveEditorMainWindow::slotFullScreen);
 
     auto manager = new KColorSchemeManager(this);
-    ac->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+    ac->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 }
 
 void SieveEditorMainWindow::slotImportImapSettings()
@@ -465,3 +463,5 @@ QUrl SieveEditorMainWindow::currentHelpUrl() const
 {
     return mMainWidget->sieveEditorMainWidget()->currentHelpUrl();
 }
+
+#include "moc_sieveeditormainwindow.cpp"
