@@ -5,7 +5,6 @@
 */
 
 #include "userfeedbackmanager.h"
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/ApplicationVersionSource>
 #include <KUserFeedbackQt6/LocaleInfoSource>
 #include <KUserFeedbackQt6/PlatformInfoSource>
@@ -14,16 +13,6 @@
 #include <KUserFeedbackQt6/ScreenInfoSource>
 #include <KUserFeedbackQt6/StartCountSource>
 #include <KUserFeedbackQt6/UsageTimeSource>
-#else
-#include <KUserFeedback/ApplicationVersionSource>
-#include <KUserFeedback/LocaleInfoSource>
-#include <KUserFeedback/PlatformInfoSource>
-#include <KUserFeedback/Provider>
-#include <KUserFeedback/QtVersionSource>
-#include <KUserFeedback/ScreenInfoSource>
-#include <KUserFeedback/StartCountSource>
-#include <KUserFeedback/UsageTimeSource>
-#endif
 
 UserFeedBackManager::UserFeedBackManager(QObject *parent)
     : QObject(parent)
@@ -56,3 +45,5 @@ KUserFeedback::Provider *UserFeedBackManager::userFeedbackProvider() const
 {
     return mUserFeedbackProvider;
 }
+
+#include "moc_userfeedbackmanager.cpp"
